@@ -5,15 +5,15 @@
 
 GeoFit2 <- function(data, coordx, coordy=NULL,coordz=NULL, coordt=NULL, coordx_dyn=NULL,copula=NULL,corrmodel, distance="Eucl",
                          fixed=NULL,anisopars=NULL,est.aniso=c(FALSE,FALSE), grid=FALSE, likelihood='Marginal', 
-                         lower=NULL,maxdist=Inf,neighb=NULL,
-                          maxtime=Inf, memdist=TRUE,method="cholesky", model='Gaussian',n=1, onlyvar=FALSE ,
-                          optimizer='Nelder-Mead',
-                         radius=1,  sensitivity=FALSE,sparse=FALSE, start=NULL, taper=NULL, tapsep=NULL, 
-                         type='Pairwise', upper=NULL, varest=FALSE, weighted=FALSE,X=NULL,nosym=FALSE,spobj=NULL,spdata=NULL)
+                         lower=NULL,maxdist=Inf,neighb=NULL,p_neighb=1,
+                          maxtime=Inf, memdist=TRUE,method="cholesky", model='Gaussian',n=1, onlyvar=FALSE ,optimizer='Nelder-Mead',
+                         radius=1,  score=FALSE,sensitivity=FALSE,sparse=FALSE, start=NULL,
+                         thin_method="iid",type='Pairwise', upper=NULL, varest=FALSE, weighted=FALSE,X=NULL,nosym=FALSE,spobj=NULL,spdata=NULL)
 {
 
 ###########  first preliminary check  ###############
     call <- match.call()
+    suppressWarnings({
 
     if(is.null(CkModel(model))) stop("The name of the  model  is not correct\n")
     if(!is.null(copula))
@@ -50,7 +50,7 @@ spacetime<-CheckST(CkCorrModel(corrmodel))
 
 space=!spacetime&&!bivariate
 
-
+taper=NULL;tapsep=NULL
 ###### checking if neighb or maxdist or maxtime has been specified when using cl
 if(space||bivariate){
      if( type=='Pairwise'&&(likelihood=='Marginal'||likelihood=='Conditional')) 
@@ -110,7 +110,7 @@ if(model %in% c("Weibull","Poisson","Binomial","Gamma","LogLogistic","PoissonGam
       stop(checkinput$error)
     ### Initialization global variables:
     GeoFit <- NULL
-    score <- sensmat <- varcov <- varimat <- parscale <- NULL
+    sensmat <- varcov <- varimat <- parscale <- NULL
     ### Initialization parameters:
     cooordt=unname(coordt);
     if(is.null(coordx_dyn)){
@@ -119,7 +119,7 @@ if(model %in% c("Weibull","Poisson","Binomial","Gamma","LogLogistic","PoissonGam
     initparam <- WlsStart(coordx, coordy, coordz,coordt, coordx_dyn, corrmodel, data, distance, "Fitting", fixed, grid,#10
                          likelihood, maxdist,neighb,maxtime,  model, n, NULL,#16
                          parscale, optimizer=='L-BFGS-B', radius, start, taper, tapsep,#22
-                         type, varest,  weighted, copula,X,memdist,nosym)#32
+                         type, varest,  weighted, copula,X,memdist,nosym,p_neighb,thin_method)#32
   
   ## in the case on external fixed mean
   MM=NULL
@@ -172,7 +172,7 @@ fitted_ini<-CompIndLik2(initparam$bivariate,initparam$coordx,initparam$coordy,in
                                     initparam$lower,initparam$model,initparam$n ,
                                      initparam$namescorr,initparam$namesnuis,
                                    initparam$namesparam,initparam$numparam,optimizer,onlyvar, initparam$param,initparam$spacetime,initparam$type,#27
-                                   initparam$upper,names(upper),varest, initparam$ns, unname(initparam$X),sensitivity,copula,MM)
+                                   initparam$upper,names(upper),varest, initparam$ns, unname(initparam$X),sensitivity,copula,MM,FALSE)
 ######################################################
 ######updating starting and names  parameters 
 ######################################################
@@ -229,7 +229,7 @@ if(!is.null(anisopars)) {
                                initparam$namesnuis,initparam$namesparam,initparam$numcoord,initparam$numpairs,
                                initparam$numparamcorr,initparam$numtime,optimizer,onlyvar,
                                initparam$param,initparam$radius,initparam$setup,initparam$spacetime,sparse,varest,taper,initparam$type,
-                               initparam$upper,initparam$ns,unname(initparam$X),initparam$neighb,MM,aniso)
+                               initparam$upper,initparam$ns,unname(initparam$X),initparam$neighb,MM,aniso,score)
 
     # Composite likelihood:
     if((likelihood=='Marginal' || likelihood=='Conditional' || likelihood=='Marginal_2')&&type=="Pairwise"){
@@ -243,7 +243,7 @@ if(!is.null(anisopars)) {
                                    initparam$namesparam,initparam$numparam,initparam$numparamcorr,optimizer,onlyvar,
                                    initparam$param,initparam$spacetime,initparam$type,#27
                                    initparam$upper,varest,initparam$weighted,initparam$ns,
-                                   unname(initparam$X),sensitivity,MM,aniso)
+                                   unname(initparam$X),sensitivity,MM,aniso,score)
     if(memdist)
         fitted <- CompLik2(copula,initparam$bivariate,initparam$coordx,initparam$coordy,initparam$coordz,initparam$coordt,
                                    coordx_dyn,initparam$corrmodel,unname(initparam$data), #6
@@ -253,7 +253,7 @@ if(!is.null(anisopars)) {
                                    initparam$namesparam,initparam$numparam,initparam$numparamcorr,optimizer,onlyvar,
                                    initparam$param,initparam$spacetime,initparam$type,#27
                                    initparam$upper,varest,initparam$weighted,initparam$ns,
-                                   unname(initparam$X),sensitivity,initparam$colidx,initparam$rowidx,initparam$neighb,MM,aniso)
+                                   unname(initparam$X),sensitivity,initparam$colidx,initparam$rowidx,initparam$neighb,MM,aniso,score)
       }
 
 
@@ -381,6 +381,7 @@ if (model %in% c("Weibull", "Poisson", "Binomial", "Gamma",
                          numtime=initparam$numtime,
                          optimizer=optimizer,
                          param = as.list(fitted$par),
+                         p_neighb=p_neighb,
                          nozero = initparam$setup$nozero,
                          score = fitted$score,
                          maxdist =maxdist,
@@ -400,6 +401,7 @@ if (model %in% c("Weibull", "Poisson", "Binomial", "Gamma",
                          weighted=initparam$weighted,
                          X = X)
     structure(c(GeoFit, call = call), class = c("GeoFit"))
+    })
   }
 
 print.GeoFit <- function(x, digits = max(3, getOption("digits") - 3), ...)
