@@ -4,11 +4,22 @@ GeoVariogramDir <- function(data, coordx, coordy = NULL, coordz = NULL,
                             numbins = 13,
                             maxdist = NULL,
                             neighb = NULL,
-                            distance = "Eucl") {
-  # Check input and set defaults
-  n <- length(data)
+                            distance = "Eucl",
+                            subsample = 1) {
+  # ---------------- Checks ----------------
+  if (!is.numeric(subsample) || length(subsample) != 1L || !is.finite(subsample) ||
+      subsample <= 0 || subsample > 1) {
+    stop("subsample must be a single numeric value in (0,1].")
+  }
+
+  if (!is.numeric(tolerance) || length(tolerance) != 1L || tolerance <= 0 || tolerance > 90)
+    stop("tolerance must be in (0,90].")
+  if (!is.numeric(numbins) || length(numbins) != 1L || numbins < 2 || numbins %% 1 != 0)
+    stop("numbins must be an integer >= 2.")
+
+  # ---------------- Build coords ----------------
   is_matrix <- is.matrix(coordx) || is.data.frame(coordx)
-  
+
   if (is_matrix) {
     coords <- as.matrix(coordx)
     if (!(ncol(coords) %in% c(2,3))) stop("coordx must have 2 or 3 columns if matrix/data.frame.")
@@ -16,100 +27,103 @@ GeoVariogramDir <- function(data, coordx, coordy = NULL, coordz = NULL,
     if (is.null(coordy)) stop("If coordx is a vector, coordy must be provided.")
     coords <- if (is.null(coordz)) cbind(coordx, coordy) else cbind(coordx, coordy, coordz)
   }
-  
+
+  n0 <- nrow(coords)
+  if (length(data) != n0) stop("length(data) must match number of coordinate rows.")
+
+  # ---------------- EARLY spatial subsample ----------------
+  if (subsample < 1) {
+    m <- max(2L, floor(subsample * n0))
+    m <- min(m, n0)
+    idx0 <- sort(sample.int(n0, m, replace = FALSE))
+
+    coords <- coords[idx0, , drop = FALSE]
+    data   <- data[idx0]
+  }
+
+  # update n after subsample
+  n <- length(data)
+
+  # ---------------- Defaults ----------------
   if (is.null(maxdist)) maxdist <- Inf
-  
+
   # Smart neighb selection based on n and maxdist
   if (is.null(neighb)) {
     if (is.finite(maxdist)) {
-      # Estimate expected neighbors within maxdist based on spatial density
       if (ncol(coords) == 2) {
         area_total <- diff(range(coords[,1])) * diff(range(coords[,2]))
+        if (!is.finite(area_total) || area_total <= 0) stop("Degenerate coordinate extent after subsample.")
         density <- n / area_total
         area_circle <- pi * maxdist^2
         expected_neighb <- density * area_circle
-        # Use 2x expected to ensure good coverage
-        neighb <- min(n - 1, max(100, as.integer(expected_neighb * 2)))
+        neighb <- min(n - 1L, max(100L, as.integer(expected_neighb * 2)))
       } else {
-        # 3D case: use volume-based estimate
         volume_total <- diff(range(coords[,1])) * diff(range(coords[,2])) * diff(range(coords[,3]))
+        if (!is.finite(volume_total) || volume_total <= 0) stop("Degenerate coordinate extent after subsample.")
         density <- n / volume_total
         volume_sphere <- (4/3) * pi * maxdist^3
         expected_neighb <- density * volume_sphere
-        neighb <- min(n - 1, max(100, as.integer(expected_neighb * 2)))
+        neighb <- min(n - 1L, max(100L, as.integer(expected_neighb * 2)))
       }
     } else {
-      # Without maxdist: use ALL neighbors (chunking will handle memory)
-      neighb <- n - 1
+      neighb <- n - 1L
     }
+  } else {
+    if (!is.numeric(neighb) || length(neighb) != 1L || neighb < 1 || neighb %% 1 != 0)
+      stop("neighb must be a positive integer.")
+    neighb <- min(as.integer(neighb), n - 1L)
   }
-  
-  # Estimate memory and determine chunk size
-  # Each pair needs ~24 bytes (3 doubles: dist, angle component, angle component)
-  memory_estimate_mb <- (n * neighb * 24) / 1e6
-  n_pairs_total <- n * neighb
-  
+
   # Adaptive chunking based on neighb size
   if (neighb < 500) {
-    # Small neighb: can process in larger chunks
-    chunk_size <- n  # No chunking needed
+    chunk_size <- n
   } else if (neighb < 5000) {
-    # Medium neighb: moderate chunks (~1GB target)
-    chunk_size <- max(500, min(n, as.integer(1000e6 / (neighb * 24))))
+    chunk_size <- max(500L, min(n, as.integer(1000e6 / (neighb * 24))))
   } else {
-    # Large neighb: small chunks (~500MB target)
-    chunk_size <- max(100, min(n, as.integer(500e6 / (neighb * 24))))
+    chunk_size <- max(100L, min(n, as.integer(500e6 / (neighb * 24))))
   }
-  
-  # Precompute distance bins
+
+  # ---------------- Distance bins ----------------
   if (is.finite(maxdist)) {
     maxdist_bin <- maxdist
   } else {
-    # Estimate from sample if n is large
     if (n > 10000) {
       samp <- sample(n, min(1000, n))
       dists_samp <- as.matrix(dist(coords[samp, ]))
-      maxdist_bin <- quantile(dists_samp[upper.tri(dists_samp)], 0.95)
+      maxdist_bin <- as.numeric(quantile(dists_samp[upper.tri(dists_samp)], 0.95, na.rm = TRUE))
     } else {
       xr <- range(coords[,1], na.rm = TRUE)
       yr <- range(coords[,2], na.rm = TRUE)
       maxdist_bin <- sqrt(diff(xr)^2 + diff(yr)^2)
     }
   }
-  
-#  breaks <- seq(0, maxdist_bin, length.out = numbins + 1)
-#  centers <- breaks[-1] - diff(breaks)/2
-#  numvario <- numbins
-#  mm <- c(breaks[1], tail(breaks, 1))
 
+  breaks   <- seq(0, maxdist_bin, length.out = numbins + 1)
+  widths   <- diff(breaks)
+  centers  <- breaks[-1] - widths/2
+  numvario <- numbins
+  mm       <- c(breaks[1L], breaks[length(breaks)])
 
-breaks   <- seq(0, maxdist_bin, length.out = numbins + 1)
-widths   <- diff(breaks)                     # larghezze dei bin
-centers  <- breaks[-1] - widths/2            # centri dei bin
-numvario <- numbins                          # <— serve più avanti
-mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
-  
-  # Precompute directional angle ranges
+  # ---------------- Directional ranges ----------------
   ang_min <- (directions - tolerance) %% 180
   ang_max <- (directions + tolerance) %% 180
   ndir <- length(directions)
-  
-  # Initialize accumulators for each direction
+
   sums_dir <- replicate(ndir, numeric(numvario), simplify = FALSE)
   cnts_dir <- replicate(ndir, integer(numvario), simplify = FALSE)
-  
+
   # Helper function: C binning
   .bin_pairs_c <- function(dist_sub, i_sub, j_sub) {
     np <- length(dist_sub)
     if (np == 0L) return(list(moms = numeric(numvario), lbins = integer(numvario)))
-    
+
     zi <- data[i_sub]
     zj <- data[j_sub]
-    
+
     binsC  <- double(numbins + 1)
     lbinsC <- integer(numvario)
     momsC  <- double(numvario)
-    
+
     EV <- dotCall64::.C64(
       "Binned_Variogram2new",
       SIGNATURE = c("double","integer","double","double","double","integer","double","integer","double"),
@@ -127,50 +141,34 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
     )
     list(moms = EV$moms, lbins = EV$lbins)
   }
-  
-  # Helper: geodesic distance functions
+
+  # ---------------- Distance type ----------------
   use_geo <- distance %in% c("Geo", "Chor")
-  
+
   proj_sinusoidal <- function(M) {
-    # Project lat/lon to sinusoidal for KNN search
     lon <- M[,1] * pi / 180
     lat <- M[,2] * pi / 180
     cbind(lon * cos(lat), lat)
   }
-  
-  chord_from_arc <- function(theta) {
-    2 * sin(theta / 2)
-  }
-  
-  # Prepare coordinates for KNN
-  if (use_geo) {
-    coords_knn <- proj_sinusoidal(coords)
-  } else {
-    coords_knn <- coords
-  }
-  
-  # Process data in chunks
+
+  chord_from_arc <- function(theta) 2 * sin(theta / 2)
+
+  coords_knn <- if (use_geo) proj_sinusoidal(coords) else coords
+
+  # ---------------- Chunk processing ----------------
   n_chunks <- ceiling(n / chunk_size)
-  
- # if (n_chunks > 1) {
- #   message(sprintf("Processing %d points in %d chunks (neighb=%d, ~%.0f MB per chunk)", 
- #                   n, n_chunks, neighb, (chunk_size * neighb * 24) / 1e6))
- # }
-  
+
   for (chunk_id in seq_len(n_chunks)) {
     start_idx <- (chunk_id - 1) * chunk_size + 1
     end_idx <- min(chunk_id * chunk_size, n)
     chunk_indices <- start_idx:end_idx
     n_chunk <- length(chunk_indices)
-    
-    # KNN search for this chunk
+
     query_coords <- coords_knn[chunk_indices, , drop = FALSE]
-    
+
     if (is.finite(maxdist)) {
-      # With radius constraint
       if (use_geo) {
-        # Approximate radius in projected space (conservative)
-        radius_proj <- maxdist * 1.1  # slight overestimate for safety
+        radius_proj <- maxdist * 1.1
         knn_res <- nabor::knn(coords_knn, query_coords, k = neighb + 1, radius = radius_proj)
       } else {
         knn_res <- nabor::knn(coords_knn, query_coords, k = neighb + 1, radius = maxdist)
@@ -178,31 +176,30 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
     } else {
       knn_res <- nabor::knn(coords_knn, query_coords, k = neighb + 1)
     }
-    
+
     idx_mat <- knn_res$nn.idx
     dists_knn <- knn_res$nn.dists
-    
+
     # Compute true distances for geodesic cases
     if (use_geo) {
       n_query <- nrow(query_coords)
       K <- ncol(idx_mat)
       dist_true <- matrix(NA_real_, n_query, K)
-      
+
       for (r in seq_len(n_query)) {
         idx <- idx_mat[r, ]
         valid <- idx > 0
         if (!any(valid)) next
-        
+
         global_idx <- chunk_indices[r]
         neighbor_idx <- idx[valid]
-        
-        # Compute geodesic distances
+
         arc <- fields::rdist.earth.vec(
           x1 = matrix(coords[global_idx, 1:2], nrow = 1),
           x2 = coords[neighbor_idx, 1:2, drop = FALSE],
           miles = FALSE, R = 1
         )
-        
+
         if (distance == "Chor") {
           dist_true[r, which(valid)] <- chord_from_arc(arc)
         } else {
@@ -213,22 +210,17 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
     } else {
       dist_mat <- dists_knn
     }
-    
-    # Filter valid pairs and apply maxdist constraint
+
     keep <- idx_mat > 0
-    if (is.finite(maxdist)) {
-      keep <- keep & (dist_mat <= maxdist)
-    }
-    
+    if (is.finite(maxdist)) keep <- keep & (dist_mat <= maxdist)
     if (!any(keep)) next
-    
-    # Flatten to pair lists
-    row_indices <- matrix(rep(chunk_indices, times = ncol(idx_mat)), 
-                         nrow = n_chunk, byrow = FALSE)
+
+    row_indices <- matrix(rep(chunk_indices, times = ncol(idx_mat)),
+                          nrow = n_chunk, byrow = FALSE)
     i <- as.integer(row_indices[keep])
     j <- as.integer(idx_mat[keep])
     dist <- as.double(dist_mat[keep])
-    
+
     # Remove self-pairs
     self_pairs <- i == j
     if (any(self_pairs)) {
@@ -236,15 +228,12 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
       j <- j[!self_pairs]
       dist <- dist[!self_pairs]
     }
-    
     if (length(i) == 0) next
-    
-    # Compute angles
+
     dx <- coords[j, 1] - coords[i, 1]
     dy <- coords[j, 2] - coords[i, 2]
     angle <- (atan2(dy, dx) * 180 / pi) %% 180
-    
-    # Compute directional masks
+
     mask_dir_mat <- matrix(FALSE, nrow = length(angle), ncol = ndir)
     for (k in seq_along(directions)) {
       if (ang_min[k] < ang_max[k]) {
@@ -253,14 +242,11 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
         mask_dir_mat[,k] <- (angle >= ang_min[k]) | (angle <= ang_max[k])
       }
     }
-    
-    # Auto-select binning method: use C if > 5000 pairs in this chunk
+
     n_pairs_chunk <- length(i)
     use_c_chunk <- n_pairs_chunk > 5000
-    
-    # Accumulate for each direction
+
     if (use_c_chunk) {
-      # C binning (faster for large chunks)
       for (k in seq_along(directions)) {
         mask <- mask_dir_mat[,k]
         if (any(mask)) {
@@ -270,10 +256,9 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
         }
       }
     } else {
-      # R binning (simpler for small chunks)
       diff2 <- (data[j] - data[i])^2 / 2
       bin_idx_all <- cut(dist, breaks, labels = FALSE, include.lowest = TRUE)
-      
+
       for (k in seq_along(directions)) {
         mask <- mask_dir_mat[,k]
         if (any(mask)) {
@@ -289,11 +274,11 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
       }
     }
   }
-  
-  # Compile results
+
+  # ---------------- Results ----------------
   result <- vector("list", ndir)
   names(result) <- paste0("dir_", directions, "deg")
-  
+
   for (k in seq_len(ndir)) {
     cnt <- cnts_dir[[k]]
     gamma <- ifelse(cnt > 0, sums_dir[[k]] / cnt, NA_real_)
@@ -303,13 +288,15 @@ mm       <- c(breaks[1L], breaks[length(breaks)])  # oppure: range(breaks)
       npairs = as.numeric(cnt)
     )
   }
-  
+
   attr(result, "breaks") <- breaks
   attr(result, "maxdist") <- maxdist_bin
   attr(result, "neighb") <- neighb
   attr(result, "n_chunks") <- n_chunks
+  attr(result, "subsample") <- subsample
   structure(result, class = "GeoVariogramDir")
 }
+
 ################################################################################
 plot.GeoVariogramDir <- function(x, ...,
                                  main = "Directional Empirical Semivariograms",
