@@ -40,7 +40,7 @@ print.GeoWLS <- function(x, digits = max(3, getOption("digits") - 3), ...)
 WlsStart <- function(coordx, coordy, coordz,coordt, coordx_dyn, corrmodel, data, distance, fcall, fixed, grid,
                     likelihood, maxdist, neighb,maxtime, model, n, param, 
                     parscale, paramrange, radius, start, taper, tapsep, type, varest, 
-                    weighted, copula,X,memdist,nosym)
+                    weighted, copula,X,memdist,nosym,p_neighb,thin_method)
   {
   
     # Determines the range of the parameters for a given correlation
@@ -150,7 +150,7 @@ WlsStart <- function(coordx, coordy, coordz,coordt, coordx_dyn, corrmodel, data,
     initparam <- StartParam(coordx, coordy, coordz,coordt, coordx_dyn, corrmodel, data, distance, fcall, fixed,
                            grid, likelihood, maxdist,neighb, maxtime, model, n, 
                            param, parscale, paramrange, radius,  start, taper, tapsep,
-                           "GeoWLS", type,  weighted,copula, X, memdist, nosym)
+                           "GeoWLS", type,  weighted,copula, X, memdist, nosym, p_neighb,thin_method)
   
 
     
@@ -355,7 +355,7 @@ GeoWLS <- function(data, coordx, coordy=NULL,coordz=NULL, coordt=NULL,  coordx_d
     parscale <- NULL
     initparam <- StartParam(coordx, coordy, coordz,coordt, coordx_dyn,corrmodel, data, distance, "Fitting", fixed, grid,
     'None', maxdist, neighb,maxtime,  model, NULL,  NULL,parscale, TRUE, radius, start,NULL,  NULL,
-                           'GeoWLS', 'GeoWLS', FALSE, NULL,NULL, FALSE,FALSE)
+                           'GeoWLS', 'GeoWLS', FALSE, NULL,NULL, FALSE,FALSE,"iid")
 
 
     if(!is.null(initparam$error))
