@@ -1,5 +1,11 @@
 #include "header.h"
 
+double clamp_corr(double x) {
+    const double eps = 1e-12;
+    if (x >  1.0 - eps) return  1.0 - eps;
+    return x;
+}
+
  
 /***********************Legendre polinomial****************************************/
 
